		------------------------------------
		-- Paragon Reputation 1.07 by Sev --
		------------------------------------	
		
local faction = CreateFrame("FRAME") -- FactionName
local math = CreateFrame("FRAME") -- ReputationMath
local id = {} -- FactionID
local rep = {} -- FactionRep
local gain = {} -- FactionRepGain

faction:RegisterEvent("PLAYER_LOGIN"); -- RegisterLogin/Reload
math:RegisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE"); -- RegisterReputationMessage

		------------------
		-- Localization --
		------------------
		
local LOCALE = GetLocale()
local l = {} -- "Paragon"

if LOCALE == "esES" or LOCALE == "esMX" then
	l = "Paragón" -- Spanish
elseif LOCALE == "zhCN" or LOCALE == "zhTW" then
	l = "巅峰" -- Chinese
elseif LOCALE == "itIT" then
	l = "Eccellenza" -- Italian
elseif LOCALE == "ptBR" then
	l = "Paragão" -- Portuguese
elseif LOCALE == "deDE" then
	l = "Huldigend" -- German
elseif LOCALE == "frFR" then
	l = "Parangon" -- French
elseif LOCALE == "ruRU" then
	l = "Идеал" -- Russian
elseif LOCALE == "koKR" then
	l = "불멸의 동맹" -- Korean
else
	l = "Paragon" -- English (DEFAULT)
end

		----------------------------------------
		-- Get Paragon Reputations and Values --
		----------------------------------------

faction:SetScript("OnEvent",function()
	local factionIndex = 1
	repeat
		local name, _, _, _, _, _, _, _, _, _, _, _, _, factionID = GetFactionInfo(factionIndex);
		if factionID and C_Reputation.IsFactionParagon(factionID) then
			local currentValue = C_Reputation.GetFactionParagonInfo(factionID);
			table.insert(faction,name)
			table.insert(id,factionID)
			table.insert(rep,currentValue)
			table.insert(gain,0)
		end
	factionIndex = factionIndex + 1
	until factionIndex > 200
end)

		-------------------------------
		-- Calculate Reputation Gain --
		-------------------------------

math:SetScript("OnEvent",function(_,_,msg,...)
	for n = 1, #faction do
		local msgrep = gsub(FACTION_STANDING_INCREASED_GENERIC,"%%s",faction[n]);
		if string.match(msgrep, msg) then
			local currentValue = C_Reputation.GetFactionParagonInfo(id[n]);
			gain[n] = currentValue - rep[n]
			rep[n] = rep[n] + gain[n]
		end
	end
end)

		--------------------------------
		-- Filter Reputation Messages --
		--------------------------------

ChatFrame_AddMessageEventFilter("CHAT_MSG_COMBAT_FACTION_CHANGE",function(_,_,msg,...)
	for n = 1, #faction do
		local msgrep = gsub(FACTION_STANDING_INCREASED_GENERIC,"%%s",faction[n]);
		if string.match(msgrep, msg) then
			msg=format(FACTION_STANDING_INCREASED,faction[n],gain[n])
		end
	end
	return false,msg,...
end)

		----------------------
		-- Reputation Frame --
		----------------------|

hooksecurefunc("ReputationFrame_Update", function(showLFGPulse)
    ReputationFrame.paragonFramesPool:ReleaseAll();
    local numFactions = GetNumFactions();
    local factionOffset = FauxScrollFrame_GetOffset(ReputationListScrollFrame);
    for i=1, NUM_FACTIONS_DISPLAYED, 1 do
        local factionIndex = factionOffset + i;
        local factionRow = _G["ReputationBar"..i];
        local factionBar = _G["ReputationBar"..i.."ReputationBar"];
        local factionStanding = _G["ReputationBar"..i.."ReputationBarFactionStanding"];
        if ( factionIndex <= numFactions ) then
            local _, _, _,_, _, _, _, _, _, _, _, _, _, factionID, _, _ = GetFactionInfo(factionIndex);
            if factionID and C_Reputation.IsFactionParagon(factionID) then
                local currentValue, threshold, _, hasRewardPending = C_Reputation.GetFactionParagonInfo(factionID);
                local value = mod(currentValue, threshold);
                if hasRewardPending then
                    local paragonFrame = ReputationFrame.paragonFramesPool:Acquire();
                    paragonFrame.factionID = factionID;
                    paragonFrame:SetPoint("RIGHT", factionRow, 11, 0);
					paragonFrame.Glow:SetShown(hasRewardPending);
                    paragonFrame:Show();
                    value = value + threshold
                end
                factionBar:SetMinMaxValues(0, threshold);
				if db.profile.color then
					factionBar:SetStatusBarColor(0, db.profile.color.g, db.profile.color.b);
				else
					factionBar:SetStatusBarColor(0, 0.5, 0.9);
				end
                factionBar:SetValue(value);
                factionRow.rolloverText = HIGHLIGHT_FONT_COLOR_CODE.." "..format(REPUTATION_PROGRESS_FORMAT, value, threshold)..FONT_COLOR_CODE_CLOSE;
				if db.profile.toggletext then
					if db.profile.toggletext.dft == true then
						factionStanding:SetText(l);
						factionRow.standingText = l;
					elseif db.profile.toggletext.vls == true then
						factionStanding:SetText(value);
						factionRow.standingText = value;
					elseif db.profile.toggletext.nbr == true then
						factionStanding:SetText(" "..value.." / "..threshold);
						factionRow.standingText = (" "..value.." / "..threshold);
						factionRow.rolloverText = nil;
					end
				else
					factionStanding:SetText(l);
					factionRow.standingText = l;
				end
            end
        else
            factionRow:Hide();
        end
    end
end)